<?php

namespace EventPortal\Domain\Address\Models;

use EventPortal\Domain\Table\Concerns\HasTable;
use EventPortal\Domain\Venue\Models\Venue;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphTo;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use Illuminate\Support\Arr;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Address extends Model implements AuditableInterface
{
    use HasTable, Auditable;

    public const KEY = 'address';

    protected $fillable = [
        'line_1',
        'line_2',
        'line_3',
        'city',
        'area',
        'area_code',
        'country',
        'addressable_type',
        'addressable_id',
    ];

    protected $appends = [
        'formatted',
        'short_formatted',
    ];

    public function addressable(): MorphTo
    {
        return $this->morphTo();
    }

    public function venues(): MorphToMany
    {
        return $this->morphedByMany(Venue::class, 'addressable');
    }

    public static function createFromExternal(array $data, Model $model): self
    {
        return self::create([
            'line_1' => Arr::get($data, 'address.line_1'),
            'line_2' => Arr::get($data, 'address.line_2'),
            'line_3' => Arr::get($data, 'address.line_3'),
            'city' => Arr::get($data, 'address.city'),
            'area' => Arr::get($data, 'address.county'),
            'area_code' => Arr::get($data, 'address.post_code'),
            'country' => Arr::get($data, 'address.country'),
            'addressable_type' => get_class($model),
            'addressable_id' => $model->id,
        ]);
    }

    public function getFormattedAttribute(): string
    {
        $address = [
            $this->line_1,
            $this->line_2,
            $this->line_3,
            $this->city,
            $this->area,
            $this->country,
            $this->area_code,
        ];

        return implode(', ', $address);
    }

    public function getShortFormattedAttribute(): string
    {
        return "{$this->line_1}, {$this->city}";
    }
}
