<?php

namespace EventPortal\Domain\Agenda\Values;

use EventPortal\Domain\Agenda\Models\Agenda as AgendaModel;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Agenda\SessionInput;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;

class Agenda
{
    /** @var int */
    public $id;

    /** @var string */
    public $day;

    /** @var array */
    public $pathways;

    /** @var array<\EventPortal\Domain\Form\Form> */
    public $forms;

    public function __construct(AgendaModel $agendaModel)
    {
        $this->id = $agendaModel->id;
        $this->day = $agendaModel->date;
        $this->forms = $this->getForms($agendaModel->event);
        $this->pathways = $agendaModel
            ->event
            ->pathways
            ->mapInto(Pathway::class)
            ->map(function (Pathway $pathway) use ($agendaModel) {
                $pathway->sessions = $agendaModel
                    ->sessions
                    ->where('pathway_id', $pathway->id)
                    ->map(function (Session $session) {
                        return SessionInput::from($session->getAttributes())->formatForBrowser($session);
                    })
                    ->values()
                    ->toArray();

                return $pathway;
            })
            ->values()
            ->toArray();
    }

    private function getForms(Event $event): array
    {
        $form = Form::make('session.create')
            ->model(new Session)
            ->context($event)
            ->useAlternativeNames()
            ->render();

        return [
            'createSession' => $form,
            'editSession' => $form,
        ];
    }
}
