<?php

namespace EventPortal\Tests\Unit\EventVenue;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventVenue;
use EventPortal\Domain\EventVenue\Actions\AssociateToEvent;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AssociateToEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function associate_to_event()
    {
        $event = factory(Event::class)->create();
        [$venueA, $venueB, $venueC] = factory(Venue::class, 3)->create();

        (new AssociateToEvent)->execute($event, [
            $venueA->id,
            $venueC->id,
        ]);

        $this->assertEventHasVenues($event, [$venueA, $venueC]);
        $this->assertEventMissingVenue($event, $venueB);
    }

    /** @test **/
    public function does_not_associate_more_than_once()
    {
        $event = factory(Event::class)->create();
        $venue = factory(Venue::class)->create();

        (new AssociateToEvent)->execute($event, [$venue->id]);
        (new AssociateToEvent)->execute($event, [$venue->id]);

        $this->assertCount(1, EventVenue::all());
    }
}
